{
  am_pm_abbreviated => [
    "a.",
    "p.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "H:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d 'di' MMMM",
    MMMd => "d MMM",
    MMd => "d/MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "LLLL 'dal' y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "fur",
  date_format_full => "EEEE d 'di' MMMM 'dal' y",
  date_format_long => "d 'di' MMMM 'dal' y",
  date_format_medium => "dd/MM/y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "lun",
    "mar",
    "mie",
    "joi",
    "vin",
    "sab",
    "dom",
  ],
  day_format_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "lunis",
    "martars",
    "miercus",
    "joibe",
    "vinars",
    "sabide",
    "domenie",
  ],
  day_stand_alone_abbreviated => [
    "lun",
    "mar",
    "mie",
    "joi",
    "vin",
    "sab",
    "dom",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "lunis",
    "martars",
    "miercus",
    "joibe",
    "vinars",
    "sabide",
    "domenie",
  ],
  era_abbreviated => [
    "pdC",
    "ddC",
  ],
  era_narrow => [
    "pdC",
    "ddC",
  ],
  era_wide => [
    "pdC",
    "ddC",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Friulian",
  month_format_abbreviated => [
    "Zen",
    "Fev",
    "Mar",
    "Avr",
    "Mai",
    "Jug",
    "Lui",
    "Avo",
    "Set",
    "Otu",
    "Nov",
    "Dic",
  ],
  month_format_narrow => [
    "Z",
    "F",
    "M",
    "A",
    "M",
    "J",
    "L",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Zen\N{U+00e2}r",
    "Fevr\N{U+00e2}r",
    "Mar\N{U+00e7}",
    "Avr\N{U+00ee}l",
    "Mai",
    "Jugn",
    "Lui",
    "Avost",
    "Setembar",
    "Otubar",
    "Novembar",
    "Dicembar",
  ],
  month_stand_alone_abbreviated => [
    "Zen",
    "Fev",
    "Mar",
    "Avr",
    "Mai",
    "Jug",
    "Lui",
    "Avo",
    "Set",
    "Otu",
    "Nov",
    "Dic",
  ],
  month_stand_alone_narrow => [
    "Z",
    "F",
    "M",
    "A",
    "M",
    "J",
    "L",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Zen\N{U+00e2}r",
    "Fevr\N{U+00e2}r",
    "Mar\N{U+00e7}",
    "Avr\N{U+00ee}l",
    "Mai",
    "Jugn",
    "Lui",
    "Avost",
    "Setembar",
    "Otubar",
    "Novembar",
    "Dicembar",
  ],
  name => "Friulian",
  native_language => "furlan",
  native_name => "furlan",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Prin trimestri",
    "Secont trimestri",
    "Tier\N{U+00e7} trimestri",
    "Cuart trimestri",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Prin trimestri",
    "Secont trimestri",
    "Tier\N{U+00e7} trimestri",
    "Cuart trimestri",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}
