{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d 'de' MMM 'de' 'su' y G",
    GyMMMd => "d 'de' MMM 'de' 'su' y G",
    GyMd => "dd/MM/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d 'de' MMM",
    "MMMMW-count-one" => "'chida' W 'de' MMMM",
    "MMMMW-count-other" => "'chida' W 'de' MMMM",
    MMMMd => "d 'de' MMMM",
    MMMd => "d 'de' MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d 'de' MMM y",
    yMMMM => "MMMM 'de' 'su' y",
    yMMMd => "d 'de' MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ 'de' 'su' y",
    "yw-count-one" => "'chida' w 'de' 'su' Y",
    "yw-count-other" => "'chida' w 'de' 'su' Y",
  },
  code => "sc-IT",
  date_format_full => "d 'de' MMMM 'de' 'su' y, 'de' EEEE",
  date_format_long => "d 'de' MMMM 'de' 'su' y",
  date_format_medium => "d 'de' MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} 'a' 'sas' {0}",
  datetime_format_long => "{1} 'a' 'sas' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "lun",
    "mar",
    "m\N{U+00e8}r",
    "gi\N{U+00f2}",
    "che",
    "s\N{U+00e0}b",
    "dom",
  ],
  day_format_narrow => [
    "L",
    "M",
    "M",
    "G",
    "C",
    "S",
    "D",
  ],
  day_format_wide => [
    "lunis",
    "martis",
    "m\N{U+00e8}rcuris",
    "gi\N{U+00f2}bia",
    "chen\N{U+00e0}bura",
    "s\N{U+00e0}badu",
    "dom\N{U+00ec}niga",
  ],
  day_stand_alone_abbreviated => [
    "lun",
    "mar",
    "m\N{U+00e8}r",
    "gi\N{U+00f2}",
    "che",
    "s\N{U+00e0}b",
    "dom",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "G",
    "C",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "lunis",
    "martis",
    "m\N{U+00e8}rcuris",
    "gi\N{U+00f2}bia",
    "chen\N{U+00e0}bura",
    "s\N{U+00e0}badu",
    "dom\N{U+00ec}niga",
  ],
  era_abbreviated => [
    "a.C.",
    "p.C.",
  ],
  era_narrow => [
    "a.C.",
    "p.C.",
  ],
  era_wide => [
    "in antis de Cristu",
    "a pustis de Cristu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %e %b %Y %H:%M:%S %Z",
  glibc_date_format => "%d. %m. %y",
  glibc_datetime_format => "%a %d %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Sardinian",
  month_format_abbreviated => [
    "ghe",
    "fre",
    "mar",
    "abr",
    "maj",
    "l\N{U+00e0}m",
    "tr\N{U+00ec}",
    "aus",
    "cab",
    "stG",
    "stA",
    "nad",
  ],
  month_format_narrow => [
    "G",
    "F",
    "M",
    "A",
    "M",
    "L",
    "T",
    "A",
    "C",
    "S",
    "S",
    "N",
  ],
  month_format_wide => [
    "ghenn\N{U+00e0}rgiu",
    "fre\N{U+00e0}rgiu",
    "martzu",
    "abrile",
    "maju",
    "l\N{U+00e0}mpadas",
    "tr\N{U+00ec}ulas",
    "austu",
    "cabudanni",
    "santugaine",
    "santandria",
    "nadale",
  ],
  month_stand_alone_abbreviated => [
    "ghe",
    "fre",
    "mar",
    "abr",
    "maj",
    "l\N{U+00e0}m",
    "tr\N{U+00ec}",
    "aus",
    "cab",
    "stG",
    "stA",
    "nad",
  ],
  month_stand_alone_narrow => [
    "G",
    "F",
    "M",
    "A",
    "M",
    "L",
    "T",
    "A",
    "C",
    "S",
    "S",
    "N",
  ],
  month_stand_alone_wide => [
    "ghenn\N{U+00e0}rgiu",
    "fre\N{U+00e0}rgiu",
    "martzu",
    "abrile",
    "maju",
    "l\N{U+00e0}mpadas",
    "tr\N{U+00ec}ulas",
    "austu",
    "cabudanni",
    "santugaine",
    "santandria",
    "nadale",
  ],
  name => "Sardinian Italy",
  native_language => "sardu",
  native_name => "sardu It\N{U+00e0}lia",
  native_script => undef,
  native_territory => "It\N{U+00e0}lia",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1u trimestre",
    "2u trimestre",
    "3u trimestre",
    "4u trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1u trimestre",
    "2u trimestre",
    "3u trimestre",
    "4u trimestre",
  ],
  script => undef,
  territory => "Italy",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}
